| daily_uvb | R Documentation |
This function extracts total daily vitamin D-effective UVB dose on a given date and geographical location (longitude and latitude).
daily_uvb(
data,
date,
longitude,
latitude,
temis_path = getwd(),
region = "europe"
)
data |
data frame containing sample IDs, date, longitude, and latitude |
date |
A date vector, usually date of assessment or recruitment. |
longitude |
A numeric vector of longitude values. |
latitude |
A numeric vector of latitude values. |
temis_path |
Path to TEMIS UV files downloaded using temis_uvdvc. Default is current directory. |
region |
Region of TEMIS data required, options are "europe" (default) or "world". |
A numeric vector of daily ambient UVB dose measurements.
#uses sample TEMIS file
mysample <- data.frame(id = c("1000016"),
date = as.Date(c("2010-08-04")),
longitude = c(-2.10),
latitude = c(50.5))
uvb_example <- system.file("extdata", "uvb_example", package="UVdose")
daily_uvb(mysample, date, longitude, latitude, temis_path = uvb_example)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.