latitude: Un-project Transverse Mercator Eastings and Northings back to...

View source: R/OSGB_lon_lat.R

latitudeR Documentation

Un-project Transverse Mercator Eastings and Northings back to latitude and longitude.

Description

These functions convert OSGB (Ordnance Survey of Great Britain) coordinates, i.e. Transverse Mercator easting and northing coordinates, for example, as provided by the UK Biobank. latitude returns latitude values and longitude returns longitude values.

Usage

latitude(data, easting, northing)

longitude(data, easting, northing)

Arguments

data

a data frame containing OSGB coordinates

easting

a numeric vector of easting coordinates

northing

a numeric vector of northing coordinates

Value

A numeric vector of latitude or longitude values.

Examples

osgb <- data.frame(east = c(393000, 461000, 438000), north = c(287000, 223000, 565000))
latitude(osgb, east, north)
longitude(osgb, east, north)

UVdose documentation built on Nov. 5, 2025, 7:38 p.m.