Learn R Programming

UVdose (version 0.1.1)

annual_uve: Annual erythemal UV

Description

This function extracts mean or cumulative erythemal UV dose at a given date and geographical location (longitude and latitude), over one year prior to the index date.

Usage

annual_uve(
  data,
  date,
  longitude,
  latitude,
  temis_path = getwd(),
  type = "cumulative",
  region = "europe"
)

Value

A numeric vector of mean or cumulative annual erythemal UV dose estimates.

Arguments

data

data frame containing sample IDs, date, longitude, and latitude

date

A date vector, usually date of assessment or recruitment.

longitude

A numeric vector of longitude values.

latitude

A numeric vector of latitude values.

temis_path

Path to TEMIS UV files downloaded using temis_uvdec. Default is current directory.

type

Type of annual dose to be calculated, cumulative (default) or mean.

region

Region of TEMIS data required, options are "europe" (default) or "world".

Examples

Run this code
#uses sample TEMIS file
mysample <- data.frame(id = c("id000016"),
        date = as.Date(c("2010-08-04")),
        longitude = c(-2.10),
        latitude = c(50.5))
uve_example <- system.file("extdata", "uve_example", package="UVdose")
annual_uve(mysample, date, longitude, latitude, temis_path=uve_example)

Run the code above in your browser using DataLab