latitude: Un-project Transverse Mercator Eastings and Northings back to latitude and longitude.
Description
These functions convert OSGB (Ordnance Survey of Great Britain) coordinates, i.e. Transverse Mercator easting and northing coordinates,
for example, as provided by the UK Biobank.
latitude returns latitude values and longitude returns longitude values.