| season_uve | R Documentation |
This function estimates mean or cumulative erythemal UV dose over a period of months (<1 year) prior to an index date, at a given geographical location (longitude and latitude).
season_uve(
data,
date,
longitude,
latitude,
temis_path = getwd(),
season = "summer",
type = "cumulative",
region = "europe"
)
data |
data frame containing sample IDs, date, longitude, and latitude |
date |
A date vector, usually date of assessment or recruitment. |
longitude |
A numeric vector of longitude values. |
latitude |
A numeric vector of latitude values. |
temis_path |
Path to TEMIS UV files downloaded using temis_uvdec. Default is current directory. |
season |
The duration over which erythemal UV dose is to be estimated. One of "summer" covering April to September (default), "winter" covering October to March, or a numeric vector corresponding to month range. |
type |
Type of annual dose to be calculated, cumulative (default) or mean. |
region |
Region of TEMIS data required, options are "europe" (default) or "world". |
A numeric vector of mean or cumulative seasonal erythemal UV dose estimates.
#uses sample TEMIS file
mysample <- data.frame(id = c("id000016"),
date = as.Date(c("2010-08-04")),
longitude = c(-2.10),
latitude = c(50.5))
uve_example <- system.file("extdata", "uve_example", package="UVdose")
season_uve(mysample, date, longitude, latitude, temis_path=uve_example, season = c(1:3,11:12))
season_uve(mysample, date, longitude, latitude, temis_path=uve_example, season = "summer")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.